@@ -310,7 +310,7 @@ AppLinkProvider::AppLinkProvider():
 #else
     mXdgMenu = new XdgMenu();
     mXdgMenu->setEnvironments(QStringList() << QSL("X-LXQT") << QSL("LXQt"));
-    connect(mXdgMenu, SIGNAL(changed()), this, SLOT(update()));
+    connect(mXdgMenu, &XdgMenu::changed, this, &AppLinkProvider::update);
     mXdgMenu->read(XdgMenu::getMenuFileName());
     update();
 #endif
@@ -792,6 +792,7 @@ bool VirtualBoxProvider::isOutDated() const
 
 #ifdef MATH_ENABLED
 #include <muParser.h>
+#include <QClipboard>
 
 class MathItem::Parser : private mu::Parser
 {
@@ -842,7 +843,7 @@ MathItem::MathItem():
         CommandProviderItem(),
         mParser{new Parser}
 {
-    mToolTip =QObject::tr("Mathematics");
+    mToolTip = QObject::tr("Copy calculation result to clipboard");
     mIcon = QIcon::fromTheme(QSL("accessories-calculator"));
 }
 
@@ -860,6 +861,12 @@ MathItem::~MathItem()
  ************************************************/
 bool MathItem::run() const
 {
+    int posResult = mTitle.indexOf(QL1C('='));
+    if (posResult > -1 && posResult < mTitle.size() - 1)
+    {
+        QApplication::clipboard()->setText(mTitle.mid(posResult + 1));
+        return true;
+    }
     return false;
 }
 
@@ -968,10 +975,9 @@ CommandProvider(), mName(name)
 {
     mExternalProcess = new QProcess(this);
     mYamlParser = new YamlParser();
-    connect(mYamlParser, SIGNAL(newListOfMaps(QList<QMap<QString, QString> >)),
-            this,        SLOT(newListOfMaps(QList<QMap<QString, QString> >)));
+    connect(mYamlParser, &YamlParser::newListOfMaps, this, &ExternalProvider::newListOfMaps);
 
-    connect(mExternalProcess, SIGNAL(readyRead()), this, SLOT(readFromProcess()));
+    connect(mExternalProcess, &QProcess::readyRead, this, &ExternalProvider::readFromProcess);
     mExternalProcess->start(externalProgram, QStringList());
 }
 
