@@ -49,7 +49,12 @@
         <translation> елементи</translation>
     </message>
     <message>
-        <location filename="../configuredialog/configuredialog.ui" line="90"/>
+        <location filename="../configuredialog/configuredialog.ui" line="80"/>
+        <source>Clear input on launching</source>
+        <translation>Изчистване на въведеното за стартиране</translation>
+    </message>
+    <message>
+        <location filename="../configuredialog/configuredialog.ui" line="97"/>
         <source>Shortcut:</source>
         <translation>Клавишна комбинация:</translation>
     </message>
@@ -97,7 +102,7 @@
         <translation>Изчистване на историята</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="374"/>
+        <location filename="../dialog.cpp" line="408"/>
         <source>Show/hide runner dialog</source>
         <translation>Показване/скриване диалог на runner</translation>
     </message>
