@@ -49,7 +49,12 @@
         <translation> elemento(s)</translation>
     </message>
     <message>
-        <location filename="../configuredialog/configuredialog.ui" line="90"/>
+        <location filename="../configuredialog/configuredialog.ui" line="80"/>
+        <source>Clear input on launching</source>
+        <translation>Borrar la entrada al inicio</translation>
+    </message>
+    <message>
+        <location filename="../configuredialog/configuredialog.ui" line="97"/>
         <source>Shortcut:</source>
         <translation>Atajo:</translation>
     </message>
@@ -97,7 +102,7 @@
         <translation>Vaciar histórico</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="374"/>
+        <location filename="../dialog.cpp" line="408"/>
         <source>Show/hide runner dialog</source>
         <translation>Mostrar/ocultar el diálogo del iniciador de aplicaciones</translation>
     </message>
