@@ -49,7 +49,12 @@
         <translation> entrée(s)</translation>
     </message>
     <message>
-        <location filename="../configuredialog/configuredialog.ui" line="90"/>
+        <location filename="../configuredialog/configuredialog.ui" line="80"/>
+        <source>Clear input on launching</source>
+        <translation>Effacer l&apos;entrée au lancement</translation>
+    </message>
+    <message>
+        <location filename="../configuredialog/configuredialog.ui" line="97"/>
         <source>Shortcut:</source>
         <translation>Raccourci :</translation>
     </message>
@@ -97,7 +102,7 @@
         <translation>Effacer l&apos;historique</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="374"/>
+        <location filename="../dialog.cpp" line="408"/>
         <source>Show/hide runner dialog</source>
         <translation>Afficher/cacher le dialogue du lanceur</translation>
     </message>
