@@ -49,7 +49,12 @@
         <translation> item(s)</translation>
     </message>
     <message>
-        <location filename="../configuredialog/configuredialog.ui" line="90"/>
+        <location filename="../configuredialog/configuredialog.ui" line="80"/>
+        <source>Clear input on launching</source>
+        <translation>Invoer wissen na opstarten</translation>
+    </message>
+    <message>
+        <location filename="../configuredialog/configuredialog.ui" line="97"/>
         <source>Shortcut:</source>
         <translation>Sneltoets:</translation>
     </message>
@@ -97,7 +102,7 @@
         <translation>Geschiedenis wissen</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="374"/>
+        <location filename="../dialog.cpp" line="408"/>
         <source>Show/hide runner dialog</source>
         <translation>Uitvoerdervenster tonen/verbergen</translation>
     </message>
