@@ -49,7 +49,12 @@
         <translation> öge(ler)</translation>
     </message>
     <message>
-        <location filename="../configuredialog/configuredialog.ui" line="90"/>
+        <location filename="../configuredialog/configuredialog.ui" line="80"/>
+        <source>Clear input on launching</source>
+        <translation>Başlangıçta girişi temizle</translation>
+    </message>
+    <message>
+        <location filename="../configuredialog/configuredialog.ui" line="97"/>
         <source>Shortcut:</source>
         <translation>Kısayol:</translation>
     </message>
@@ -97,7 +102,7 @@
         <translation>Geçmişi Temizle</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="374"/>
+        <location filename="../dialog.cpp" line="408"/>
         <source>Show/hide runner dialog</source>
         <translation>Çalıştırıcı penceresini göster/gizle</translation>
     </message>
