@@ -49,9 +49,14 @@
         <translation> елемент(ів)</translation>
     </message>
     <message>
-        <location filename="../configuredialog/configuredialog.ui" line="90"/>
+        <location filename="../configuredialog/configuredialog.ui" line="80"/>
+        <source>Clear input on launching</source>
+        <translation>Очищувати поле під час запуску</translation>
+    </message>
+    <message>
+        <location filename="../configuredialog/configuredialog.ui" line="97"/>
         <source>Shortcut:</source>
-        <translation>Клавіатурне скорочення:</translation>
+        <translation>Комбінація клавіш:</translation>
     </message>
     <message>
         <location filename="../configuredialog/configuredialog.cpp" line="61"/>
@@ -61,7 +66,7 @@
     <message>
         <location filename="../configuredialog/configuredialog.cpp" line="62"/>
         <source>Center of the screen</source>
-        <translation>Центр екрану</translation>
+        <translation>Центр екрана</translation>
     </message>
     <message>
         <location filename="../configuredialog/configuredialog.cpp" line="67"/>
@@ -97,7 +102,7 @@
         <translation>Очистити історію</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="374"/>
+        <location filename="../dialog.cpp" line="408"/>
         <source>Show/hide runner dialog</source>
         <translation>Показати/сховати діалог запускача</translation>
     </message>
